Graph classes
=============

.. currentmodule:: nngt
.. autoclass:: Graph
   :inherited-members:
   :no-undoc-members:

.. currentmodule:: nngt
.. autoclass:: SpatialGraph

.. currentmodule:: nngt
.. autoclass:: Network

.. currentmodule:: nngt
.. autoclass:: SpatialNetwork
